@@ -23,7 +23,7 @@
 #include <R.h>
 #include <Rinternals.h>
 #include <Rdefines.h>
-#include "zoo.h"
+#include <zoo.h>
 
 SEXP zoo_lag (SEXP x, SEXP _k, SEXP _pad)
 {
@@ -42,15 +42,20 @@ Rprintf("zoo_lag\n");
   int P=0;
   int PAD = INTEGER(coerceVector(_pad,INTSXP))[0];
 
-  if(k > length(x))
+  if(k > nr)
     error("abs(k) must be less than nrow(x)");
 
-  if(k < 0 && -1*k > length(x))
+  if(k < 0 && -1*k > nr)
     error("abs(k) must be less than nrow(x)");
 
   PROTECT(result = allocVector(TYPEOF(x), 
           length(x) - (PAD ? 0 : abs(k)*nc))); P++;
-  int nrr = (int)(length(result)/nc);
+
+  int nrr;
+  if(length(result) > 0)
+    nrr = (int)(length(result)/nc);
+  else  /* handle zero-length objects */
+    nrr = nr - (PAD ? 0 : abs(k));
 
   if(k_positive) {
   switch(TYPEOF(x)) {
